@@ -41,6 +41,7 @@ pageDataToDF <- function(json){
 		type = unlistWithNA(json, 'type'),
 		link = unlistWithNA(json, 'link'),
 		id = unlistWithNA(json, 'id'),
+		story = unlistWithNA(json, 'story'),
 		likes_count = unlistWithNA(json, c('likes', 'summary', 'total_count')),
 		comments_count = unlistWithNA(json, c('comments', 'summary', 'total_count')),
 		shares_count = unlistWithNA(json, c('shares', 'count')),
@@ -127,6 +128,24 @@ likesDataToDF <- function(json){
 }
 
 commentsDataToDF <- function(json){
+	if (!is.null(json)){
+		df <- data.frame(
+			from_id = unlistWithNA(json, c('from', 'id')),
+			from_name = unlistWithNA(json, c('from', 'name')),
+			message = unlistWithNA(json, 'message'),
+			created_time = unlistWithNA(json, 'created_time'),
+			likes_count = unlistWithNA(json, 'like_count'),
+			comments_count = unlistWithNA(json, 'comment_count'),
+			id = unlistWithNA(json, 'id'),
+		stringsAsFactors=F)
+	}
+	if (is.null(json)){
+		df <- NULL
+	}
+	return(df)
+}
+
+repliesDataToDF <- function(json){
 	if (!is.null(json)){
 		df <- data.frame(
 			from_id = unlistWithNA(json, c('from', 'id')),
@@ -218,6 +237,19 @@ tagsDataToDF <- function(tags){
     return(tags)
 }
 
+replyDataToDF <- function(json){
+  df <- data.frame(
+    from_id = json$from$id,
+    from_name = json$from$name,
+    message = ifelse(!is.null(json$message),json$message, NA),
+    created_time = json$created_time,
+    likes_count = json$like_count,
+	comments_count = json$comment_count,
+    id = json$id,
+	stringsAsFactors=F)
+  return(df)
+}
+
 
 unlistWithNA <- function(lst, field){
 	if (length(field)==1){
